#!/bin/bash

#
# guess the DNS domainname:
# if dnsdomainname gives something sensible, use it
#    exludes "localdomain" and similar, should have a "."
# otherwise try to guess based on the IP on the "default gateway" interface
# may fail completely e.g. for NATed machines on a private network
#   we could use "traceroute" to discover this, but why bother?

export LANG=C

if [[ -x /sbin/ip && -x /usr/bin/host && -x /bin/dnsdomainname  ]]  ; then
 full=1
else
 full=0
fi

guess_default_if_name() {
  [ $full == 1 ] && 
  local defdev_tmp=$(/sbin/ip route show scope global) || 
  local defdev_tmp=$(/sbin/busybox iproute list | /sbin/busybox grep default)
  local defdev=${defdev_tmp##default via*dev }

  if [ -z "$defdev" ]; then
    return 1
  fi

  [ $full == 1 ] &&
  local def_ip_tmp1=$(/sbin/ip -o -f inet addr show scope global dev ${defdev}) ||
  local def_ip_tmp1=$(/sbin/busybox ipaddr show dev ${defdev} | /sbin/busybox grep "inet ")
  
  local def_ip_tmp2=${def_ip_tmp1%%/?? brd*}
  local def_ip=${def_ip_tmp2##*inet }

  if [ -z "$def_ip" -o -n "${def_ip//*.*.*.*}" ]; then
    return 1
  fi

  [ $full == 1 ] &&
  local def_name_tmp1=$(/usr/bin/host ${def_ip}) ||
  # OK, looking-up pre-defined name server is not so cool, but we have no choice here .. 
  # in install env. nothing else will work
  local def_name_tmp1=$(/sbin/busybox nslookup ${def_ip} 137.138.16.5 | /sbin/busybox grep "Name:")
  [ $full == 1 ] &&
  local def_name_tmp2=${def_name_tmp1##*pointer } ||
  local def_name_tmp2=${def_name_tmp1##Name: }
  def_name=${def_name_tmp2%%.}
  if [ "$def_name" != "${def_name//Host*not found*}" ]; then
     def_name=''
     return 1
  fi


  # special and unfortunate hack for the CERN Technical Network
  case "$def_ip" in
      172.18.*)
	 def_name=somewhere.tn.cern.ch
         ;;
  esac
  #$def_name
}


dnsdom=$(/bin/dnsdomainname) 
guess_default_if_name
if [ -n "$def_name" ]; then
  dom=${def_name#*.}
elif [ -n "$dnsdom" -a -z "${dnsdom//*.*}" ]; then
  dom="$dnsdom"
else
  # tough luck
  dom=""
fi

echo "$dom"




